@@ -1,3 +1,4 @@
+import collections
 import importlib
 import inspect
 import logging
@@ -10,12 +11,15 @@ from pathlib import Path
 from typing import Any, Callable, Dict, Optional, Type, Union
 
 import pytorch_lightning as pl
+import torch
+from pytorch_lightning.core.saving import _load_state
 from pytorch_lightning.plugins import TorchCheckpointIO
 
 METADATA_KEY: str = "metadata"
 
 pylogger = logging.getLogger(__name__)
 
+from typing import Mapping
 
 _METADATA_MODULE_KEY = f"{METADATA_KEY}_module"
 _METADATA_CLASS_KEY = f"{METADATA_KEY}_class"
@@ -91,7 +95,7 @@ class NNCheckpointIO(TorchCheckpointIO):
 
 
 def compress_checkpoint(src_dir: Path, dst_file: Path, delete_dir: bool = True):
-
+    dst_file.parent.mkdir(parents=True, exist_ok=True)
     with zipfile.ZipFile(_normalize_path(dst_file), "w") as zip_file:
         for folder, subfolders, files in os.walk(src_dir):
             folder: Path = Path(folder)
@@ -123,8 +127,42 @@ def extract_checkpoint(ckpt_file: Path) -> Path:
         yield Path(tmp_dir)
 
 
-def load_model(module_class: Type[pl.LightningModule], checkpoint_path: Path):
-    checkpoint = NNCheckpointIO.load(path=checkpoint_path)
+def _substistute(dictionary, substitute_values: Dict[str, str], substitute_keys: Dict[str, str] = {}):
+    if not isinstance(dictionary, Mapping):
+        if isinstance(dictionary, collections.Hashable):
+            if substitute_values is not None and dictionary in substitute_values:
+                return substitute_values[dictionary]
+            elif substitute_keys is not None and dictionary in substitute_keys:
+                return substitute_keys[dictionary]
+            else:
+                return dictionary
+        return dictionary
 
-    model = module_class._load_model_state(checkpoint=checkpoint, metadata=checkpoint["metadata"])
-    return model
+    return {
+        _substistute(key, substitute_values=substitute_values, substitute_keys=substitute_keys,): _substistute(
+            value,
+            substitute_values=substitute_values,
+            substitute_keys=substitute_keys,
+        )
+        for key, value in dictionary.items()
+    }
+
+
+def load_model(
+    module_class: Type[pl.LightningModule],
+    checkpoint_path: Path,
+    map_location: Optional[Union[Dict[str, str], str, torch.device, int, Callable]] = None,
+    substitute_keys: Optional[Dict[str, str]] = None,
+    substitute_values: Optional[Dict[str, str]] = None,
+):
+    # Lightning checkpoints end with .ckpt, ours with .ckpt.zip
+    if checkpoint_path.name.endswith(".ckpt.zip"):
+        checkpoint = NNCheckpointIO.load(path=checkpoint_path, map_location=map_location)
+
+        if substitute_values is not None:
+            checkpoint = _substistute(checkpoint, substitute_values=substitute_values, substitute_keys=substitute_keys)
+
+        return _load_state(cls=module_class, checkpoint=checkpoint, metadata=checkpoint.get("metadata", None))
+    else:
+        pylogger.warning(f"Loading a legacy checkpoint (from vanilla PyTorch Lightning): '{checkpoint_path}'")
+        module_class.load_from_checkpoint(checkpoint_path=str(checkpoint_path), map_location=map_location)
